==> release.12.0.73.1.tgz: prontus/cpan/js-local/Recordarpass.class.js <==
var Recordarpass = {
    dir_cgi_cpan: '',
    prontus_id: '',

    init: function() {
        Recordarpass.dir_cgi_cpan = Admin.dir_cgi_cpn;
        Recordarpass.prontus_id = $("body").attr("data-prontus-id");
        $('.button-back').on('click', function() {
            history.back();
            return false;
        });
        $('.button-send').on('click', function() {
            Recordarpass.recordar();
            return false;
        });

        $('#_usr').on('blur', function () {
            Recordarpass.validaUsr();
        });

        $('#_code').on('blur', function () {
            Recordarpass.validaCode();
        });

        var prop = {type:'cpan'};
        Captcha.generate(prop);

        $('#FrmRecordar').bind('submit', function() {
                Captcha.setRefreshCaptcha();
        });
    },

    validaCode: function() {
        if ($('#_code').val() == '') {
            Recordarpass.mostrarAlerta('Debes ingresar el código de validación');
            $('#_code').focus();
            return false;
        }
        return true;


    },

    validaUsr: function() {
        if ($('#_usr').val() == '') {
            Recordarpass.mostrarAlerta('Debes ingresar el usuario');
            $('#_usr').focus();
            return false;
        }
        return true;
    },

    recordar: function() {
        if (!Recordarpass.validaUsr()) {
            return false;
        }
        if (!Recordarpass.validaCode()) {
            return false;
        }

        var configAjax = {
            formSelector: '#FrmRecordar',
            actionURL:  '/' + Recordarpass.dir_cgi_cpan + '/prontus_recordarpass.cgi',
            redirURL:   '/' + Recordarpass.dir_cgi_cpan + '/prontus_index.cgi?_prontus_id=' + Recordarpass.prontus_id,
            okMsg:      'La nueva contraseña ha sido enviada a tu email registrado en Prontus.'
        };

        var optAjax = {
            success: function (data) {
                if (typeof data.status != 'undefined') {
                    if (data.status == '0') {
                        Recordarpass.mostrarAlerta(unescape(data.msg));
                        Captcha.generate();
                        $('.loading-action').hide();
                        $('.box-request-pwd').show();
                        $('#_code').focus();
                    } else if (data.status == '1') {
                        Recordarpass.mostrarAlerta(unescape(data.msg), true);
                        setTimeout(function() {
                            window.location.href = configAjax.redirURL;
                        }, 4000);
                    }
                }
            }
        };

        $('#box-alert').hide();
        $('.loading-action').show()
        $('.box-request-pwd').hide();
        SubmitForm.submitGenericAjax(configAjax, optAjax);
    },

    mostrarAlerta: function(msg, success) {
        if (success) {
            $('#box-alert').removeClass('alert-danger alert-next-crit').addClass('alert-success');
        }
        $('#box-alert span.msg').html(msg);
        $('#box-alert span.sr-only').html(msg);
        $('#box-alert').show();
    }
};

$(document).ready(function() {
    Recordarpass.init();
});

==> release.12.3.1.2.tgz: prontus/cpan/js-local/Recordarpass.class.js <==
var Recordarpass = {
    dir_cgi_cpan: '',
    prontus_id: '',

    init: function() {
        Recordarpass.dir_cgi_cpan = Admin.dir_cgi_cpn;
        Recordarpass.prontus_id = $("body").attr("data-prontus-id");
        $('.button-back').on('click', function() {
            history.back();
            return false;
        });
        $('.button-send').on('click', function() {
            Recordarpass.recordar();
            return false;
        });

        $('#_usr').on('blur', function () {
            Recordarpass.validaUsr();
        });

        $('#_code').on('blur', function () {
            Recordarpass.validaCode();
        });

        var prop = {type:'cpan'};
        Captcha.generate(prop);

        $('#FrmRecordar').bind('submit', function() {
                Captcha.setRefreshCaptcha();
        });
    },

    validaCode: function() {
        if ($('#_code').val() == '') {
            Recordarpass.mostrarAlerta(ProntusL10n.get('recordarpass_validation_code'));
            $('#_code').focus();
            return false;
        }
        return true;


    },

    validaUsr: function() {
        if ($('#_usr').val() == '') {
            Recordarpass.mostrarAlerta(ProntusL10n.get('recordarpass_enter_user'));
            $('#_usr').focus();
            return false;
        }
        return true;
    },

    recordar: function() {
        if (!Recordarpass.validaUsr()) {
            return false;
        }
        if (!Recordarpass.validaCode()) {
            return false;
        }

        var configAjax = {
            formSelector: '#FrmRecordar',
            actionURL:  '/' + Recordarpass.dir_cgi_cpan + '/prontus_recordarpass.cgi',
            redirURL:   '/' + Recordarpass.dir_cgi_cpan + '/prontus_index.cgi?_prontus_id=' + Recordarpass.prontus_id,
            okMsg:      ProntusL10n.get('recordarpass_new_pass')
        };

        var optAjax = {
            success: function (data) {
                if (typeof data.status != 'undefined') {
                    if (data.status == '0') {
                        Recordarpass.mostrarAlerta(unescape(data.msg));
                        Captcha.generate();
                        $('.loading-action').hide();
                        $('.box-request-pwd').show();
                        $('#_code').focus();
                    } else if (data.status == '1') {
                        Recordarpass.mostrarAlerta(unescape(data.msg), true);
                        setTimeout(function() {
                            window.location.href = configAjax.redirURL;
                        }, 4000);
                    }
                }
            }
        };

        $('#box-alert').hide();
        $('.loading-action').show()
        $('.box-request-pwd').hide();
        SubmitForm.submitGenericAjax(configAjax, optAjax);
    },

    mostrarAlerta: function(msg, success) {
        if (success) {
            $('#box-alert').removeClass('alert-danger alert-next-crit').addClass('alert-success');
        }
        $('#box-alert span.msg').html(msg);
        $('#box-alert span.sr-only').html(msg);
        $('#box-alert').show();
    }
};

$(document).ready(function() {
    Recordarpass.init();
});
